@@ -26,5 +26,6 @@ import androidx.lifecycle.MutableLiveData
 import androidx.lifecycle.ViewModel
 
 class ScannerViewModel : ViewModel() {
-    val status = MutableLiveData<String>()
+    val modalMessage = MutableLiveData<String>()
+    val showModal = MutableLiveData<Boolean>()
 }
\ No newline at end of file
